@@ -176,8 +176,8 @@ sub _thread_main {
    _thread_threshold( $self, $request->{threshold}, $request->{page} );
   }
 
-  elsif ( $request->{action} eq 'to-tiff' ) {
-   _thread_to_tiff( $self, $request->{page} );
+  elsif ( $request->{action} eq 'to-png' ) {
+   _thread_to_png( $self, $request->{page} );
   }
 
   elsif ( $request->{action} eq 'unpaper' ) {
@@ -212,7 +212,7 @@ sub _thread_get_file_info {
  my ( $self, $filename, $pidfile, %info ) = @_;
 
  $logger->info("Getting info for $filename");
- my $format = `file -b $filename`;
+ my $format = `file -b "$filename"`;
 
  if ( $format =~ /gzip compressed data/ ) {
   $info{path}   = $filename;
@@ -351,11 +351,12 @@ sub _thread_import_file {
    my @images = glob('x-???.???');
    my $i      = 0;
    foreach (@images) {
+    my $png = convert_to_png( $_ );
     my $page = Gscan2pdf::Page->new(
-     filename => $_,
+     filename => $png,
      dir      => $self->{dir},
      delete   => TRUE,
-     format   => 'Portable anymap'
+     format   => 'Portable Network Graphics'
     );
     $self->{page_queue}->enqueue( $page->freeze );
    }
@@ -385,8 +386,10 @@ sub _thread_import_file {
    }
   }
  }
+
+ # only 1-bit Portable anymap is properly supported, so convert ANY pnm to tif
  elsif ( $info->{format} =~
-/(Portable anymap|Portable Network Graphics|Joint Photographic Experts Group JFIF format|CompuServe graphics interchange format)/
+/(Portable Network Graphics|Joint Photographic Experts Group JFIF format|CompuServe graphics interchange format)/
    )
  {
   my $page = Gscan2pdf::Page->new(
@@ -397,48 +400,53 @@ sub _thread_import_file {
   $self->{page_queue}->enqueue( $page->freeze );
  }
  else {
-  my $tiff = convert_to_tiff( $info->{path} );
+  my $png = convert_to_png( $info->{path} );
   return if $_self->{cancel};
   my $page = Gscan2pdf::Page->new(
-   filename => $tiff,
+   filename => $png,
    dir      => $self->{dir},
-   format   => 'Tagged Image File Format'
+   format   => 'Portable Network Graphics'
   );
   $self->{page_queue}->enqueue( $page->freeze );
  }
  return;
 }
 
-sub convert_to_tiff {
+sub convert_to_png {
  my ($filename) = @_;
  my $image      = Image::Magick->new;
  my $x          = $image->Read($filename);
- return if $_self->{cancel};
  $logger->warn($x) if "$x";
- my $density = Gscan2pdf::Document::get_resolution($image)
-   ; # FIXME: most of the time we already know this - pull it from $page->{resolution} rather than asking IM
+ return if $_self->{cancel};
 
- # Write the tif
- my $tif =
-   File::Temp->new( DIR => $_self->{dir}, SUFFIX => '.tif', UNLINK => FALSE );
+ # FIXME: most of the time we already know this -
+ # pull it from $page->{resolution} rather than asking IM
+ my $density = Gscan2pdf::Document::get_resolution($image);
+
+ # Write the png
+ my $png =
+   File::Temp->new( DIR => $_self->{dir}, SUFFIX => '.png', UNLINK => FALSE );
  $image->Write(
   units       => 'PixelsPerInch',
-  compression => 'lzw',
   density     => $density,
-  filename    => $tif
+  filename    => $png
  );
- return $tif;
+ return $png;
 }
 
 sub _thread_save_pdf {
  my ( $self, $path, $list_of_pages, $metadata, $options, $pidfile ) = @_;
 
  my $page = 0;
+ my $fontcache;
 
  # Create PDF with PDF::API2
  $self->{message} = $d->get('Setting up PDF');
  my $pdf = PDF::API2->new( -file => $path );
- $pdf->info($metadata) if defined($metadata);
+ $pdf->info(%$metadata) if defined($metadata);
+
+ $fontcache = $pdf->ttfont( $options->{font}, -unicodemap => 1 )
+   if ( defined $options->{font} );
 
  foreach my $pagedata ( @{$list_of_pages} ) {
   ++$page;
@@ -578,7 +586,7 @@ sub _thread_save_pdf {
    for my $box ( $pagedata->boxes ) {
     my ( $x1, $y1, $x2, $y2, $txt ) = @$box;
     if ( $txt =~ /[[:^ascii:]]/ and defined( $options->{font} ) ) {
-     $font = $pdf->ttfont( $options->{font}, -unicodemap => 1 );
+     $font = $fontcache;
     }
     else {
      $font = $pdf->corefont('Times-Roman');
@@ -748,7 +756,7 @@ sub _thread_save_djvu {
 
   # Create the djvu
   my $resolution = $pagedata->{resolution};
-  my $cmd        = "$compression -dpi $resolution $filename $djvu";
+  my $cmd        = sprintf "$compression -dpi %d $filename $djvu", $resolution;
   $logger->info($cmd);
   my ( $status, $size ) =
     ( system("echo $$ > $pidfile;$cmd"), -s "$djvu" )
@@ -832,7 +840,11 @@ sub _thread_save_tiff {
    $page, $#{$list_of_pages} + 1 );
 
   my $filename = $pagedata->{filename};
-  if ( $filename !~ /\.tif/ or $options->{compression} eq 'jpeg' ) {
+  if ( $filename !~ /\.tif/
+   or
+   ( defined( $options->{compression} ) and $options->{compression} eq 'jpeg' )
+    )
+  {
    my $tif = File::Temp->new( DIR => $self->{dir}, SUFFIX => '.tif' );
    my $resolution = $pagedata->{resolution};
 
@@ -990,7 +1002,7 @@ sub _thread_save_image {
 sub _thread_save_text {
  my ( $self, $path, $list_of_pages, $fh ) = @_;
 
- unless ( open $fh, ">:utf8", $path ) {    ## no critic
+ unless ( open $fh, ">", $path ) {    ## no critic
   $self->{status} = 1;
   $self->{message} = sprintf( $d->get("Can't open file: %s"), $path );
   return;
@@ -1177,10 +1189,10 @@ sub _thread_crop {
  return;
 }
 
-sub _thread_to_tiff {
+sub _thread_to_png {
  my ( $self, $page ) = @_;
  my $new = $page->clone;
- $new->{filename} = convert_to_tiff( $page->{filename} );
+ $new->{filename} = convert_to_png( $page->{filename} );
  return if $_self->{cancel};
  $new->{format} = 'Tagged Image File Format';
  my %data = ( old => $page, new => $new->freeze );
