@@ -25,10 +25,9 @@ my $_POLL_INTERVAL = 100;    # ms
 
 BEGIN {
  use Exporter ();
- our ( $VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
+ our ( $VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS );
 
- @ISA    = qw(Exporter Gtk2::Ex::Simple::List);
- @EXPORT = qw();
+ @ISA = qw(Exporter Gtk2::Ex::Simple::List);
  %EXPORT_TAGS = ();          # eg: TAG => [ qw!name1 name2! ],
 
  # your exported package globals go here,
@@ -493,7 +492,7 @@ sub save_djvu {
    }
    $started_callback->() if ( $started_callback and not $started_flag );
    if ( $Gscan2pdf::_self->{status} ) {
-    $error_callback->();
+    $error_callback->() if ($error_callback);
     return;
    }
    $finished_callback->( $Gscan2pdf::_self->{requests}->pending )
@@ -1072,14 +1071,14 @@ sub crop {
  return;
 }
 
-sub to_tiff {
+sub to_png {
  my ( $self, $page, $queued_callback, $started_callback, $running_callback,
   $finished_callback, $error_callback, $cancelled_callback )
    = @_;
 
  my $started_flag;
  my $sentinel =
-   Gscan2pdf::_enqueue_request( 'to-tiff', { page => $page->freeze } );
+   Gscan2pdf::_enqueue_request( 'to-png', { page => $page->freeze } );
  $queued_callback->(
   $Gscan2pdf::_self->{process_name},
   $Gscan2pdf::jobs_completed, $Gscan2pdf::jobs_total
@@ -1512,7 +1511,7 @@ sub open_session {
   @filenamelist = $tar->list_files;
   $tar->extract;
  }
- $dir = dirname( $filenamelist[0] ) unless ( defined $dir );
+ $dir = dirname( $filenamelist[0] );
  my $sessionref = retrieve( File::Spec->catfile( $dir, 'session' ) );
  my %session = %$sessionref;
 
